/*
 * Created on 27/lug/2012
 * Copyright 2011 by Andrea Vacondio (andrea.vacondio@gmail.com).
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 */
package org.test;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import org.apache.pdfbox.exceptions.COSVisitorException;
import org.apache.pdfbox.exceptions.CryptographyException;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.PDPage;
import org.apache.pdfbox.pdmodel.encryption.AccessPermission;
import org.apache.pdfbox.pdmodel.encryption.BadSecurityHandlerException;
import org.apache.pdfbox.pdmodel.encryption.DecryptionMaterial;
import org.apache.pdfbox.pdmodel.encryption.StandardDecryptionMaterial;
import org.junit.Test;

/**
 * @author Andrea Vacondio
 * 
 */
public class TestRotateEncryptedDocument {

    private static final String ENCRYPTED_WITH_MODIFY = "enc_with_modify_perm.pdf";
    private static final String ENCRYPTED_NO_PERMISSIONS = "enc_no_perm.pdf";

    @Test
    public void testWithPermissionWithOwnerPwd() throws IOException, BadSecurityHandlerException,
            CryptographyException, COSVisitorException {
        File tmp = File.createTempFile("test", ".pdf");
        tmp.deleteOnExit();

        InputStream input = getClass().getClassLoader().getResourceAsStream(ENCRYPTED_WITH_MODIFY);
        PDDocument document = PDDocument.load(input);
        try {
            DecryptionMaterial decryptionMaterial = new StandardDecryptionMaterial("test");
            document.openProtection(decryptionMaterial);
            AccessPermission permissions = document.getCurrentAccessPermission();
            assertTrue(permissions.isOwnerPermission());
            assertTrue(permissions.canModify());
            for (int j = 1; j <= document.getNumberOfPages(); j++) {
                PDPage page = (PDPage) document.getDocumentCatalog().getAllPages().get(j - 1);
                page.setRotation(page.findRotation() + 90);
            }
            document.save(tmp.getAbsolutePath());
        } finally {
            document.close();
            tmp.delete();
        }
    }

    @Test
    public void testWithPermissionNoPwd() throws COSVisitorException, IOException {
        File tmp = File.createTempFile("test", ".pdf");
        tmp.deleteOnExit();

        InputStream input = getClass().getClassLoader().getResourceAsStream(ENCRYPTED_WITH_MODIFY);
        PDDocument document = PDDocument.load(input);
        try {
            AccessPermission permissions = document.getCurrentAccessPermission();
            // assertFalse(permissions.isOwnerPermission());
            // assertTrue(permissions.canModify());
            for (int j = 1; j <= document.getNumberOfPages(); j++) {
                PDPage page = (PDPage) document.getDocumentCatalog().getAllPages().get(j - 1);
                page.setRotation(page.findRotation() + 90);
            }
            document.save(tmp.getAbsolutePath());
        } finally {
            document.close();
            tmp.delete();
        }
    }

    @Test
    public void testNoPermissionWithOwnerPwd() throws IOException, BadSecurityHandlerException, CryptographyException,
            COSVisitorException {
        File tmp = File.createTempFile("test", ".pdf");
        tmp.deleteOnExit();

        InputStream input = getClass().getClassLoader().getResourceAsStream(ENCRYPTED_NO_PERMISSIONS);
        PDDocument document = PDDocument.load(input);
        try {
            DecryptionMaterial decryptionMaterial = new StandardDecryptionMaterial("test");
            document.openProtection(decryptionMaterial);
            AccessPermission permissions = document.getCurrentAccessPermission();
            assertTrue(permissions.isOwnerPermission());
            // assertFalse(permissions.canModify());
            for (int j = 1; j <= document.getNumberOfPages(); j++) {
                PDPage page = (PDPage) document.getDocumentCatalog().getAllPages().get(j - 1);
                page.setRotation(page.findRotation() + 90);
            }
            document.save(tmp.getAbsolutePath());
        } finally {
            document.close();
            tmp.delete();
        }
    }

}
